@@ -1,7 +1,7 @@
 """
    SDC Service model module
 """
-from sqlalchemy import Column, Integer, String, JSON
+from sqlalchemy import Column, String, JSON, DateTime
 from sqlalchemy.orm import relationship
 from sdc_helpers.models.model import Model
 from sdc_helpers.models.subscription import Subscription
@@ -14,16 +14,16 @@ class Service(Model):
     # pylint: disable=too-few-public-methods
     __tablename__ = 'services'
 
-    id = Column(Integer, primary_key=True)
     slug = Column(String(255), unique=True)
     name = Column(String(255))
     properties = Column(JSON)
     updated_by = Column(String(255))
+    deleted_at = Column(DateTime)
     subscriptions = relationship(Subscription)
 
     def __init__(self, **kwargs):
         """
-            Creation of client model
+            Creation of service model
         """
         super().__init__(**kwargs)
         self.slug = kwargs.get('slug')
